import os
import time
import shutil

from paste.script import templates
from paste.script.templates import var


class PyTemplate(templates.Template):

    _template_dir = 'templates'
    egg_plugins = ['python_template']
    summary = 'A standard, modern Python project'
    required_templates = []
    use_cheetah = True

    vars = [
        var('module_name', 'Module name (like "Project Issue")',
            default='My Module'),
        var('description', 'One-line description of the module'),
        var('keywords', 'Space-separated keywords/tags'),
        var('author', 'Author name', default=os.getlogin()),
        var('author_email', 'Author email'),
        var('url', 'URL of homepage'),
    ]

    def pre(self, command, output_dir, vars):
        """
        Called before template is applied.
        """
        # import pdb;pdb.set_trace()
        vars['license_name'] = 'Apache'
        vars['year'] = time.strftime('%Y', time.localtime())

    def post(self, command, output_dir, vars):
        template_dir = self.template_dir()
        current_dir = os.path.join(output_dir, vars['package'])

        # apparently .dotfiles are not copied by Paster
        hidden_files = ['.gitignore']
        for hf in hidden_files:
            shutil.copyfile(
                os.path.join(template_dir, hf),
                os.path.join(output_dir, hf)
            )



#!/bin/env python

from setuptools import setup, find_packages
import os

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()

setup(name='standard.paster',
      version_command=('git describe --tags --dirty', 'pep440-git'),
      description="Quickly create a standard Python module layout",
      long_description=README,
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Console',
          'Environment :: Plugins',
          'Framework :: Paste',
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          'Topic :: Software Development :: Code Generators',
      ],
      keywords='paster bootstrap',
      author='Jon Miller',
      author_email='jonEbird@gmail.com',
      url='https://github.com/jonEbird/standard-paster',
      license='Apache',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'setuptools',
          'Paste',
          'PasteScript',
          'Cheetah',
          # -*- Extra requirements: -*-
      ],
      setup_requires=["setuptools_git", "setuptools_version_command"],
      dependency_links=[],
      # tests_require=['nose'],
      entry_points="""
        # These will declare what templates paster create command can find
        # -*- Entry points: -*-
        [paste.paster_create_template]
        standard = python_template.newmodule:PyTemplate
        """
      )
